==> vtigercrm-5.0.4.tgz: vtigercrm/modules/Products/language/en_us.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 ********************************************************************************/
/*********************************************************************************
 * $Header$
 * Description:  Defines the English language pack for the Account module.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * All Rights Reserved.
 * Contributor(s): ______________________________________..
 ********************************************************************************/

$mod_strings = Array(
'LBL_MODULE_NAME'=>'Products',
'LBL_LIST_PRODUCT_NAME'=>'Product Name',
'LBL_TOOL_FORM_TITLE'=>'Product Tools',
'LBL_SEARCH_FORM_TITLE'=>'Product Search',
'LBL_PRODUCT_NAME'=>'Product Name:',
'LBL_VENDOR_NAME'=>'Vendor Name:',
'LBL_PRICEBOOK_NAME'=>'Price Book Name:',
'LBL_VENDOR'=>'Vendor',
'LBL_PRICEBOOK'=>'Price Book:',
'LBL_VENDOR_INFORMATION'=>'Vendor Information:',
'LBL_PRICEBOOK_INFORMATION'=>'Price Book Information:',
'LBL_VENDOR_ADDRESS_INFORMATION'=>'Address Information:',
'LBL_DESCRIPTION_INFORMATION'=>'Description Name:',
'LBL_PRICING_INFORMATION'=>'Pricing Information:',
'LBL_STOCK_INFORMATION'=>'Stock Information:',
'LBL_LIST_FORM_TITLE'=>'Product List',
'LBL_LIST_VENDOR_FORM_TITLE'=>'Vendor List',
'LBL_LIST_PRICEBOOK_FORM_TITLE'=>'Price Book List',
'LBL_LIST_CATEGORY'=>'Product Category',
'LBL_CATEGORY'=>'Product Category:',
'LBL_PRODUCT_CODE'=>'Part Number',
'LBL_LIST_PRODUCT_CODE'=>'Part Number:',
'LBL_PRODUCT_ACTIVE'=>'Product Active',
'LBL_PRODUCT_COMMISSION_RATE'=>'Commission Rate',
'LBL_PRODUCT_QTY_PER_UNIT'=>'Qty/Unit',
'LBL_PRODUCT_UNIT_PRICE'=>'Unit Price',
'LBL_PB_LIST_PRICE'=>'List Price',
'LBL_PRODUCT_DESCRIPTION'=>'Description',
'LBL_PRODUCT_IMAGE'=>'Image',
'LBL_NEW_FORM_TITLE'=>'New Product',
'LBL_PRODUCT_INFORMATION'=>'Product Information',
'LBL_CUSTOM_INFORMATION'=>'Custom Information',
'LBL_DESCRIPTION_INFORMATION'=>'Description Information',

//New entry
'LBL_UPLOAD'=>'Upload File',

'LBL_PRODUCT'=>'Product',
'LBL_NEW_PRODUCT'=>'New Product',
'LBL_COLON'=>':',

'LBL_ATTACHMENTS'=>'Attachments',
'LBL_ATTACH_FILE'=>'File Attachment',
'LBL_DESCRIPTION'=>'Description',
'LBL_FILE'=>'File Name',


//for v4 release added
'LBL_NEW_POTENTIAL'=>'New Potential',
'LBL_POTENTIAL_TITLE'=>'Potentials',

'LBL_NEW_TICKET'=>'New Ticket',
'LBL_TICKET_TITLE'=>'Tickets',

'LBL_NEW_CALL'=>'New Call',
'LBL_CALL_TITLE'=>'Calls',

'LBL_NEW_MEETING'=>'New Meeting',
'LBL_MEETING_TITLE'=>'Meetings',

'LBL_NEW_ATTACHMENT'=>'New Attachment',
'LBL_ATTACHMENT_TITLE'=>'Attachments',

//Added vtiger_fields after RC1 - Release
'LBL_MANUFACTURER'=>'Manufacturer',
'LBL_PRODUCTCATEGORY'=>'Product Category',
'LBL_SUPPORT_START_DATE'=>'Support Start Date',
'LBL_SUPPORT_EXPIRY_DATE'=>'Support Expiry Date',
'LBL_PURCHASE_DATE'=>'Purchase Date',

//Added for 4GA
'Product Name'=>'Product Name',
//'Product Code'=>'Part Number',
'Part Number'=>'Part Number',
'Product Active'=>'Product Active',
'Commission Rate'=>'Commission Rate (%)',
'Qty/Unit'=>'Qty/Unit',
'Unit Price'=>'Unit Price',
'Manufacturer'=>'Manufacturer',
'Product Category'=>'Product Category',
'Support Start Date'=>'Support Start Date',
'Support Expiry Date'=>'Support Expiry Date',
'Purchase Date'=>'Purchase Date',
'Sales Start Date'=>'Sales Start Date',
'Sales End Date'=>'Sales End Date',
'Created Time'=>'Created Time',
'Modified Time'=>'Modified Time',
'Related To'=>'Related To',
'Usage Unit'=>'Usage Unit',
'Handler'=>'Handler',
'Contact Name'=>'Contact Name',
'Currency'=>'Currency',
'Reorder Level'=>'Reorder Level',
'Tax Class'=>'Tax Class',
'Mfr PartNo'=>'Mfr Part No',
'Vendor PartNo'=>'Vendor Part No',
'Serial No'=>'Serial No',
'Qty In Stock'=>'Qty. in Stock',
'Product Sheet'=>'Product Sheet',
'Qty In Demand'=>'Qty. in Demand',
'GL Account'=>'GL Account',
'Vendor Name'=>'Vendor Name',

//Mapping for Name
'Name'=>'Name',
'Company Name'=>'Company Name',
'Phone'=>'Phone',
'Email'=>'Email',
'Website'=>'Website',
'GL Account'=>'GL Account',
'Category'=>'Category',
'Street'=>'Street',
'City'=>'City',
'State'=>'State',
'Postal Code'=>'Postal Code',
'Country'=>'Country',
'Description'=>'Description',
'Po Box'=>'PO Box',

//Mapping for price book
'Price Book Name'=>'Price Book Name',
'Product Name'=>'Product Name',
'Active'=>'Active',

//Added for 4.2 Release -- CustomView
'LBL_ALL'=>'All',
'LBL_VENDOR_SEARCH_FORM_TITLE'=>'Vendor Search',
'LBL_PRICEBOOK_SEARCH_FORM_TITLE'=>'PriceBook Search',
'LBL_VENDOR_TITLE'=>'Vendors',
'LBL_PRICEBOOK_TITLE'=>'Price Books',
'LBL_PRODUCTS_TITLE'=>'Products',
'LBL_COMPANY_NAME'=>'Company Name',
'LBL_CATEGORY_TITLE'=>'Category',
'LBL_ACTIVE_TITLE'=>'Active',
'LBL_LIST_VENDOR_NAME'=>'Vendor Name',
'LBL_IMAGE_INFORMATION'=>'Product Image Information:',
'Product Image'=>'Product Image',
'LBL_ADD_PRICEBOOK_BUTTON_TITLE'=>'Add To Price Books [Alt+B]',
'LBL_ADD_PRICEBOOK_BUTTON_KEY'=>'B',
'LBL_ADD_PRICEBOOK_BUTTON_LABEL'=>'Add To Price Books',
'LBL_ADD_PRODUCT_PRICEBOOKS'=>'Add Product to PriceBooks',
'LBL_ADD_PRODUCTS_PRICEBOOK'=>'Add Products to PriceBook',

//Added for 4.2 patch2 release
'LBL_MAXIMUM_LIMIT_ERROR'=>'Sorry, the uploaded file exceeds the maximum vtiger_filesize limit. Please try a file smaller than 800000 bytes',
'LBL_UPLOAD_ERROR'=>'Problems in file upload. Please try again!',
'LBL_IMAGE_ERROR'=>'The given file is not of type image(.gif/.jpg/.png)',
'LBL_INVALID_IMAGE'=>'Invalid file OR File has no data',
'LBL_EMAIL'=>'Email',
'Product'=>'Product',
'LBL_EDITLISTPRICE'=>'EditListPrice',

//Added for existing picklist entries

'--None--'=>'--None--',

'Hardware'=>'Hardware',
'Software'=>'Software',
'CRM Applications'=>'CRM Applications',

'300-Sales-Software'=>'300-Sales-Software',
'301-Sales-Hardware'=>'301-Sales-Hardware',
'302-Rental-Income'=>'302-Rental-Income',
'303-Interest-Income'=>'303-Interest-Income',
'304-Sales-Software-Support'=>'304-Sales-Software-Support',
'305-Sales Other'=>'305-Sales Other',
'306-Internet Sales'=>'306-Internet Sales',
'307-Service-Hardware Labor'=>'307-Service-Hardware Labor',
'308-Sales-Books'=>'308-Sales-Books',

'Box'=>'Box',
'Carton'=>'Carton',
'Caton'=>'Caton',
'Dozen'=>'Dazon',
'Each'=>'Each',
'Hours'=>'Hours',
'Impressions'=>'Impressions',
'Lb'=>'Lb',
'M'=>'M',
'Pack'=>'Pack',
'Pages'=>'Pages',
'Pieces'=>'Pieces',
'Quantity'=>'Quantity',
'Reams'=>'Reams',
'Sheet'=>'Sheet',
'Spiral Binder'=>'Spiral Binder',
'Sq Ft'=>'Sq Ft',

//Added for 5.0.3
'MSG_STOCK_LEVEL'=>'Stock Level is Low',
'MSG_DEAR'=>'Dear',
'MSG_CURRENT_STOCK'=>'The current stock of',
'MSG_IN_OUR_WAREHOUSE'=>'in our warehouse is',
'MSG_PROCURE_REQUIRED_NUMBER'=>'Kindly procure required number of units as the stock level is below reorder level',
'MSG_SEVERITY'=>'Severity: Major',
'MSG_THANKS'=>'Thanks,',

);

?>

==> vtigercrm-5.1.0.tgz: vtigercrm/modules/Products/language/en_us.lang.php <==
<?php
/*+**********************************************************************************
 * The contents of this file are subject to the vtiger CRM Public License Version 1.0
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved.
 ************************************************************************************/

$mod_strings = Array(
'LBL_MODULE_NAME'=>'Products',
'SINGLE_Products'=>'Product',
'LBL_LIST_PRODUCT_NAME'=>'Product Name',
'LBL_TOOL_FORM_TITLE'=>'Product Tools',
'LBL_SEARCH_FORM_TITLE'=>'Product Search',
'LBL_PRODUCT_NAME'=>'Product Name:',
'LBL_VENDOR_NAME'=>'Vendor Name:',
'LBL_PRICEBOOK_NAME'=>'Price Book Name:',
'LBL_VENDOR'=>'Vendor',
'LBL_PRICEBOOK'=>'Price Book:',
'LBL_VENDOR_INFORMATION'=>'Vendor Information:',
'LBL_PRICEBOOK_INFORMATION'=>'Price Book Information:',
'LBL_VENDOR_ADDRESS_INFORMATION'=>'Address Information:',
'LBL_DESCRIPTION_INFORMATION'=>'Description Name:',
'LBL_PRICING_INFORMATION'=>'Pricing Information:',
'LBL_STOCK_INFORMATION'=>'Stock Information:',
'LBL_LIST_FORM_TITLE'=>'Product List',
'LBL_LIST_VENDOR_FORM_TITLE'=>'Vendor List',
'LBL_LIST_PRICEBOOK_FORM_TITLE'=>'Price Book List',
'LBL_LIST_CATEGORY'=>'Product Category',
'LBL_CATEGORY'=>'Product Category:',
'LBL_PRODUCT_CODE'=>'Part Number',
'LBL_LIST_PRODUCT_CODE'=>'Part Number:',
'LBL_PRODUCT_ACTIVE'=>'Product Active',
'LBL_PRODUCT_COMMISSION_RATE'=>'Commission Rate',
'LBL_PRODUCT_QTY_PER_UNIT'=>'Qty/Unit',
'LBL_PRODUCT_UNIT_PRICE'=>'Unit Price',
'LBL_PB_LIST_PRICE'=>'List Price',
'LBL_PRODUCT_DESCRIPTION'=>'Description',
'LBL_PRODUCT_IMAGE'=>'Image',
'LBL_NEW_FORM_TITLE'=>'New Product',
'LBL_PRODUCT_INFORMATION'=>'Product Information',
'LBL_CUSTOM_INFORMATION'=>'Custom Information',
'LBL_DESCRIPTION_INFORMATION'=>'Description Information',

//New entry
'LBL_UPLOAD'=>'Upload File',

'LBL_PRODUCT'=>'Product',
'LBL_NEW_PRODUCT'=>'New Product',
'LBL_COLON'=>':',

'LBL_ATTACHMENTS'=>'Attachments',
'LBL_ATTACH_FILE'=>'File Attachment',
'LBL_DESCRIPTION'=>'Description',
'LBL_FILE'=>'File Name',

//for v4 release added
'LBL_NEW_POTENTIAL'=>'New Potential',
'LBL_POTENTIAL_TITLE'=>'Potentials',

'LBL_NEW_TICKET'=>'New Ticket',
'LBL_TICKET_TITLE'=>'Tickets',

'LBL_NEW_CALL'=>'New Call',
'LBL_CALL_TITLE'=>'Calls',

'LBL_NEW_MEETING'=>'New Meeting',
'LBL_MEETING_TITLE'=>'Meetings',

'LBL_NEW_ATTACHMENT'=>'New Attachment',
'LBL_ATTACHMENT_TITLE'=>'Attachments',

//Added vtiger_fields after RC1 - Release
'LBL_MANUFACTURER'=>'Manufacturer',
'LBL_PRODUCTCATEGORY'=>'Product Category',
'LBL_SUPPORT_START_DATE'=>'Support Start Date',
'LBL_SUPPORT_EXPIRY_DATE'=>'Support Expiry Date',
'LBL_PURCHASE_DATE'=>'Purchase Date',

//Added for 4GA
'Product Name'=>'Product Name',
//'Product Code'=>'Part Number',
'Part Number'=>'Part Number',
'Product Active'=>'Product Active',
'Commission Rate'=>'Commission Rate (%)',
'Qty/Unit'=>'Qty/Unit',
'Unit Price'=>'Unit Price',
'Manufacturer'=>'Manufacturer',
'Product Category'=>'Product Category',
'Support Start Date'=>'Support Start Date',
'Support Expiry Date'=>'Support Expiry Date',
'Purchase Date'=>'Purchase Date',
'Sales Start Date'=>'Sales Start Date',
'Sales End Date'=>'Sales End Date',
'Created Time'=>'Created Time',
'Modified Time'=>'Modified Time',
'Related To'=>'Related To',
'Usage Unit'=>'Usage Unit',
'Handler'=>'Handler',
'Contact Name'=>'Contact Name',
'Currency'=>'Currency',
'Reorder Level'=>'Reorder Level',
'Tax Class'=>'Tax Class',
'Mfr PartNo'=>'Mfr Part No',
'Vendor PartNo'=>'Vendor Part No',
'Serial No'=>'Serial No',
'Qty In Stock'=>'Qty. in Stock',
'Product Sheet'=>'Product Sheet',
'Qty In Demand'=>'Qty. in Demand',
'GL Account'=>'GL Account',
'Vendor Name'=>'Vendor Name',

//Mapping for Name
'Name'=>'Name',
'Company Name'=>'Company Name',
'Phone'=>'Phone',
'Email'=>'Email',
'Website'=>'Website',
'GL Account'=>'GL Account',
'Category'=>'Category',
'Street'=>'Street',
'City'=>'City',
'State'=>'State',
'Postal Code'=>'Postal Code',
'Country'=>'Country',
'Description'=>'Description',
'Po Box'=>'PO Box',

//Mapping for price book
'Price Book Name'=>'Price Book Name',
'Product Name'=>'Product Name',
'Active'=>'Active',

//Added for 4.2 Release -- CustomView
'LBL_ALL'=>'All',
'LBL_VENDOR_SEARCH_FORM_TITLE'=>'Vendor Search',
'LBL_PRICEBOOK_SEARCH_FORM_TITLE'=>'PriceBook Search',
'LBL_VENDOR_TITLE'=>'Vendors',
'LBL_PRICEBOOK_TITLE'=>'Price Books',
'LBL_PRODUCTS_TITLE'=>'Products',
'LBL_COMPANY_NAME'=>'Company Name',
'LBL_CATEGORY_TITLE'=>'Category',
'LBL_ACTIVE_TITLE'=>'Active',
'LBL_LIST_VENDOR_NAME'=>'Vendor Name',
'LBL_IMAGE_INFORMATION'=>'Product Image Information:',
'Product Image'=>'Product Image',
'LBL_ADD_PRICEBOOK_BUTTON_TITLE'=>'Add To Price Books [Alt+B]',
'LBL_ADD_PRICEBOOK_BUTTON_KEY'=>'B',
'LBL_ADD_PRICEBOOK_BUTTON_LABEL'=>'Add To Price Books',
'LBL_ADD_PRODUCT_PRICEBOOKS'=>'Add Product to PriceBooks',
'LBL_ADD_PRODUCTS_PRICEBOOK'=>'Add Products to PriceBook',

//Added for 4.2 patch2 release
'LBL_MAXIMUM_LIMIT_ERROR'=>'Sorry, the uploaded file exceeds the maximum vtiger_filesize limit. Please try a file smaller than 800000 bytes',
'LBL_UPLOAD_ERROR'=>'Problems in file upload. Please try again!',
'LBL_IMAGE_ERROR'=>'The given file is not of type image(.gif/.jpg/.png)',
'LBL_INVALID_IMAGE'=>'Invalid file OR File has no data',
'LBL_EMAIL'=>'Email',
'Product'=>'Product',
'LBL_EDITLISTPRICE'=>'EditListPrice',

//Added for existing picklist entries

'--None--'=>'--None--',

'Hardware'=>'Hardware',
'Software'=>'Software',
'CRM Applications'=>'CRM Applications',

'300-Sales-Software'=>'300-Sales-Software',
'301-Sales-Hardware'=>'301-Sales-Hardware',
'302-Rental-Income'=>'302-Rental-Income',
'303-Interest-Income'=>'303-Interest-Income',
'304-Sales-Software-Support'=>'304-Sales-Software-Support',
'305-Sales Other'=>'305-Sales Other',
'306-Internet Sales'=>'306-Internet Sales',
'307-Service-Hardware Labor'=>'307-Service-Hardware Labor',
'308-Sales-Books'=>'308-Sales-Books',

'Box'=>'Box',
'Carton'=>'Carton',
'Caton'=>'Caton',
'Dozen'=>'Dazon',
'Each'=>'Each',
'Hours'=>'Hours',
'Impressions'=>'Impressions',
'Lb'=>'Lb',
'M'=>'M',
'Pack'=>'Pack',
'Pages'=>'Pages',
'Pieces'=>'Pieces',
'Quantity'=>'Quantity',
'Reams'=>'Reams',
'Sheet'=>'Sheet',
'Spiral Binder'=>'Spiral Binder',
'Sq Ft'=>'Sq Ft',

//Added for 5.0.3
'MSG_STOCK_LEVEL'=>'Stock Level is Low',
'MSG_DEAR'=>'Dear',
'MSG_CURRENT_STOCK'=>'The current stock of',
'MSG_IN_OUR_WAREHOUSE'=>'in our warehouse is',
'MSG_PROCURE_REQUIRED_NUMBER'=>'Kindly procure required number of units as the stock level is below reorder level',
'MSG_SEVERITY'=>'Severity: Major',
'MSG_THANKS'=>'Thanks,',

// Added after 5.0.4 GA

'LBL_PRODUCT_PRICES'=>'Product Prices',
'Member Of'=>'Member Of',

// Module Sequence Numbering
'Product No' => 'Product No',
// END

'LBL_NO_TAXES_ASSOCIATED'=>'No taxes associated with this product',
);

?>
